@@ -38,7 +38,7 @@ class Schema:
 
     # public methods
 
-    def __init__(self, debug=False, casing=Casing.SNAKE, restrict_models_queried_fields=False, models_max_depth=None):
+    def __init__(self, debug=False, casing=Casing.SNAKE, restrict_models_queried_fields=False, models_max_depth=None, models_limit=-1):
         self.methods = defaultdict(dict)
         self.subclasses = []
         self.dirty = True
@@ -49,6 +49,7 @@ class Schema:
         self.debug = debug
         self.restrict_models_queried_fields = restrict_models_queried_fields
         self.models_max_depth = models_max_depth
+        self.models_limit = models_limit
         # abstract parent classes
         class Exposed(exposition.Exposed):
             # pylint: disable=too-few-public-methods,missing-class-docstring
@@ -84,13 +85,7 @@ class Schema:
         if not inspect.isclass(cls):
             raise ValueError('Parameter to `expose()` method should be a class, '
                 f'`{cls}` was given instead.')
-        accepted_parent_classes = (
-            exposition.ExposedQuery, exposition.ExposedMutation, exposition.ExposedModel)
-        if not issubclass(cls, accepted_parent_classes):
-            raise ValueError('Parameter to `expose()` method should be a subclass of either '
-                '`exposition.ExposedQuery`, `exposition.ExposedMutation` or '
-                f'`exposition.ExposedModel`, but `{cls}` was found instead')
-        self.subclasses.append(cls)
+        self._expose_from_subclass(cls)
 
     def expose_query(self, **options):
         """
@@ -119,6 +114,8 @@ class Schema:
             options['restrict_queried_fields'] = self.restrict_models_queried_fields
         if 'max_depth' not in options:
             options['max_depth'] = self.models_max_depth
+        if 'limit' not in options:
+            options['limit'] = self.models_limit
         model_config = ModelConfig(orm_model=orm_model, schema=self, **options)
         self.models_configs.append(model_config)
         orm_model_manager_class = model_config.orm_model_manager.__class__
@@ -218,78 +215,85 @@ class Schema:
 
     def _expose_method(self, type_, name, method, input_format=None, output_format=None,
             pass_graphql_selection=False, pass_graphql_path=False,
-            pass_authenticated_user=False, require_authenticated_user=False):
+            pass_authenticated_user=False, require_authenticated_user=False, deprecation_message=None):
         self.methods[type_][name] = GraphQLField(
-        # output format
-        type_ = to_graphql_type(
-            type_ = output_format,
-            prefix = name,
-            for_input = False,
-            schema = self,
-        ) if output_format else None,
-        # input format
-        args = to_graphql_argument(
-            type_ = input_format,
-            prefix = name,
-            schema = self,
-        ) if input_format else None,
-        # resolve method
-        resolve = self._make_callback(
-            type_ = type_,
-            method = method,
-            pass_graphql_selection = (
-                'graphql_selection'
-                if pass_graphql_selection is True else
-                pass_graphql_selection
+            # output format
+            type_ = to_graphql_type(
+                type_ = output_format,
+                prefix = name,
+                for_input = False,
+                schema = self,
+            ) if output_format else None,
+            # input format
+            args = to_graphql_argument(
+                type_ = input_format,
+                prefix = name,
+                schema = self,
+            ) if input_format else None,
+            # resolve method
+            resolve = self._make_callback(
+                type_ = type_,
+                method = method,
+                pass_graphql_selection = (
+                    'graphql_selection'
+                    if pass_graphql_selection is True else
+                    pass_graphql_selection
+                ),
+                pass_graphql_path = (
+                    'graphql_path'
+                    if pass_graphql_path is True else
+                    pass_graphql_path
+                ),
+                pass_authenticated_user = (
+                    'authenticated_user'
+                    if pass_authenticated_user is True else
+                    pass_authenticated_user
+                ),
+                require_authenticated_user = require_authenticated_user,
             ),
-            pass_graphql_path = (
-                'graphql_path'
-                if pass_graphql_path is True else
-                pass_graphql_path
-            ),
-            pass_authenticated_user = (
-                'authenticated_user'
-                if pass_authenticated_user is True else
-                pass_authenticated_user
-            ),
-            require_authenticated_user = require_authenticated_user,
-        ),
+            # deprecation
+            deprecation_reason = deprecation_message,
         )
         # schema is not up to date anymore
         self.dirty = True
 
+    def _expose_from_subclass(self, subclass):
+        subclass_attributes = introspection.get_public_class_attributes(subclass)
+        # different parent classes, different results
+        if issubclass(subclass, exposition.ExposedModel):
+            message = ' when subclassing `ExposedModel`'
+            exposition_method = self.expose_model
+            validation_method = ModelConfig
+            excluded_arguments = ('self', 'schema')
+        elif issubclass(subclass, exposition.ExposedQuery):
+            message = ' when subclassing `ExposedQuery`'
+            exposition_method = self.expose_query
+            validation_method = self._expose_method
+            excluded_arguments = ('self', 'type_')
+        elif issubclass(subclass, exposition.ExposedMutation):
+            message = ' when subclassing `ExposedMutation`'
+            exposition_method = self.expose_mutation
+            validation_method = self._expose_method
+            excluded_arguments = ('self', 'type_')
+        else:
+            raise ValueError('Parameter to `expose()` method should be a subclass of either '
+                '`exposition.ExposedQuery`, `exposition.ExposedMutation` or '
+                f'`exposition.ExposedModel`, but `{subclass}` was found instead')
+        # attributes validation
+        introspection.validate_class_attributes_against_method_arguments(
+            cls = subclass,
+            method = validation_method,
+            excluded_arguments = excluded_arguments,
+            message = message)
+        # actual exposition
+        exposition_method(**subclass_attributes)
+
     def _collect_from_classes(self):
         for subclass in introspection.get_subclasses(self.Exposed):
             if subclass not in (self.ExposedModel, self.ExposedQuery, self.ExposedMutation):
                 self.expose(subclass)
         for subclass in self.subclasses:
-            subclass_attributes = introspection.get_public_class_attributes(subclass)
-            # different parent classes, different results
-            if issubclass(subclass, exposition.ExposedModel):
-                message = ' when subclassing `ExposedModel`'
-                exposition_method = self.expose_model
-                validation_method = ModelConfig
-                excluded_arguments = ('self', 'schema')
-            elif issubclass(subclass, exposition.ExposedQuery):
-                message = ' when subclassing `ExposedQuery`'
-                exposition_method = self.expose_query
-                validation_method = self._expose_method
-                excluded_arguments = ('self', 'type_')
-            elif issubclass(subclass, exposition.ExposedMutation):
-                message = ' when subclassing `ExposedMutation`'
-                exposition_method = self.expose_mutation
-                validation_method = self._expose_method
-                excluded_arguments = ('self', 'type_')
-            else:
-                raise ValueError(f'Unrecognized class: {subclass}')
-            # attributes validation
-            introspection.validate_class_attributes_against_method_arguments(
-                cls = subclass,
-                method = validation_method,
-                excluded_arguments = excluded_arguments,
-                message = message)
-            # actual exposition
-            exposition_method(**subclass_attributes)
+            self._expose_from_subclass(subclass)
 
 
     # build schema when modified, returned cached version otherwise
